@@ -14,8 +14,8 @@
 # limitations under the License.
 
 import copy
+from unittest import mock
 
-import mock
 from oslo_utils import uuidutils
 import six
 from sqlalchemy import exc as sa_ex
@@ -458,6 +458,10 @@ class ClusterTemplates(test_base.ConductorManagerTestCase):
             ng.pop("volume_type")
             ng.pop("auto_security_group")
             ng.pop("is_proxy_gateway")
+            ng.pop("boot_from_volume")
+            ng.pop("boot_volume_type")
+            ng.pop("boot_volume_availability_zone")
+            ng.pop("boot_volume_local_to_instance")
             ng.pop('volume_local_to_instance')
 
         self.assertEqual(SAMPLE_CLT["node_groups"],
