@@ -14,8 +14,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+from unittest import mock
+
 from keystoneauth1 import exceptions as keystone_exceptions
-import mock
 from oslo_config import cfg
 
 from sahara import main
@@ -32,31 +33,48 @@ class TestCinder(test_base.SaharaTestCase):
                       **kwargs):
         self.override_config('os_region_name', 'RegionOne')
 
-        # Fake service_catalog with both volume and volumev2 services available
+        # Fake service_catalog with both volumev2
+        # and volumev3 services available
         service_catalog = '''[
             { "type": "volumev2",
               "endpoints": [ { "region": "RegionOne",
-                               "internalURL": "http://localhost/" } ] } ]'''
+                               "internalURL": "http://localhost/" } ] },
+            { "type": "volumev3",
+              "endpoints": [ { "region": "RegionOne",
+                               "internalURL": "http://localhost/" } ] }]'''
 
         super(TestCinder, self).setup_context(
             username=username, tenant_id=tenant_id, token=token,
             tenant_name=tenant_name, service_catalog=service_catalog, **kwargs)
 
     @mock.patch('sahara.utils.openstack.keystone.auth')
+    @mock.patch('cinderclient.v3.client.Client')
     @mock.patch('cinderclient.v2.client.Client')
-    def test_get_cinder_client_api_v2(self, patched, auth):
+    def test_get_cinder_client_api_v2(self, patched2, patched3, auth):
         self.override_config('api_version', 2, group='cinder')
-        patched.return_value = FakeCinderClient(2)
+        patched2.return_value = FakeCinderClient(2)
+        patched3.return_value = FakeCinderClient(3)
 
         client = cinder.client()
         self.assertEqual(2, client.client.api_version)
 
+    @mock.patch('sahara.utils.openstack.keystone.auth')
+    @mock.patch('cinderclient.v3.client.Client')
+    @mock.patch('cinderclient.v2.client.Client')
+    def test_get_cinder_client_api_v3(self, patched2, patched3, auth):
+        self.override_config('api_version', 3, group='cinder')
+        patched2.return_value = FakeCinderClient(2)
+        patched3.return_value = FakeCinderClient(3)
+
+        client = cinder.client()
+        self.assertEqual(3, client.client.api_version)
+
     def test_cinder_bad_api_version(self):
         self.override_config('api_version', 1, group='cinder')
         cinder.validate_config()
 
         # Check bad version falls back to latest supported version
-        self.assertEqual(2, main.CONF.cinder.api_version)
+        self.assertEqual(3, main.CONF.cinder.api_version)
 
     @mock.patch('sahara.utils.openstack.base.url_for')
     def test_check_cinder_exists(self, mock_url_for):
